==> mybody_api_client-0.4.1.tar.gz: mybody_api_client-0.4.1/mybody_api_client/routes/client/articles/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class ClientArticleRoute(BaseRoute):
    prefix = '/articles'

    async def get(self, id_: int):
        return await self.request(
            type_=RequestTypes.GET,
            prefix='/get',
            parameters={
                'id': id_,
            },
            response_key='article',
        )

    async def get_additional(self, id_: int, language: str = None):
        return await self.request(
            type_=RequestTypes.GET,
            prefix='/additional/get',
            parameters={
                'id': id_,
                'language': language,
            },
            response_key='article'
        )

    async def get_list(self):
        return await self.request(
            type_=RequestTypes.GET,
            prefix='/list/get',
            response_key='articles',
        )

==> mybody_api_client-0.5.21.tar.gz: mybody_api_client-0.5.21/mybody_api_client/routes/client/articles/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes


class ClientArticleRoute(BaseRoute):
    _prefix = '/articles'

    async def get(self, id_: int):
        return await self._request(
            type_=RequestTypes.GET,
            prefix='/get',
            parameters={
                'id': id_,
            },
            response_key='article',
        )

    async def get_additional(self, id_: int, language: str = None):
        return await self._request(
            type_=RequestTypes.GET,
            prefix='/additional/get',
            parameters={
                'id': id_,
                'language': language,
            },
            response_key='article'
        )

    async def get_list(self):
        return await self._request(
            type_=RequestTypes.GET,
            prefix='/list/get',
            response_key='articles',
        )
